package VMOMI::HostNetStackInstanceCongestionControlAlgorithmType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
